@@ -1,6 +1,8 @@
-/* vi:set ts=4 sts=0 sw=4:
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/*
+ * gedit
  *
- * gEdit
+ * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,22 +16,15 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
+
 #ifndef __MENUS_H__
 #define __MENUS_H__
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
-extern GnomeUIInfo gedit_menu [];
-
-extern GnomeUIInfo * gE_menus_init(gE_window *window, gE_data *data);
-void gE_set_menu_toggle_states();
-   
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+extern GnomeUIInfo gedit_menu[];
+extern GnomeUIInfo toolbar_data[];
+extern GnomeUIInfo doc_menu[];
+extern GnomeUIInfo popup_menu[];
 
 #endif /* __MENUS_H__ */
